@@ -6,7 +6,7 @@ from patchwork.common.utils.typing import IS_CONFIG
 
 
 class __ReadIssuesRequiredInputs(TypedDict):
-    issue_url: Annotated[str, IS_CONFIG]
+    issue_url: str
 
 
 class ReadIssuesInputs(__ReadIssuesRequiredInputs, total=False):
@@ -16,4 +16,6 @@ class ReadIssuesInputs(__ReadIssuesRequiredInputs, total=False):
 
 
 class ReadIssuesOutputs(TypedDict):
-    issue_text: list[str]
+    issue_title: str
+    issue_body: str
+    issue_comments: list[str]
