@@ -1,4 +1,6 @@
-from typing_extensions import Annotated, Sequence, TypedDict
+from __future__ import annotations
+
+from typing_extensions import Annotated, TypedDict
 
 from patchwork.common.utils.typing import IS_CONFIG, IS_PATH
 
@@ -6,7 +8,7 @@ from patchwork.common.utils.typing import IS_CONFIG, IS_PATH
 class ScanSemgrepInputs(TypedDict, total=False):
     sarif_file_path: Annotated[str, IS_CONFIG, IS_PATH]
     sarif_values: dict
-    semgrep_extra_args: Annotated[Sequence[str], IS_CONFIG]
+    semgrep_extra_args: Annotated[list[str], IS_CONFIG]
 
 
 class ScanSemgrepOutputs(TypedDict):
